# Bad Spence

A citation generator from digital object identifier.

## Installation

Install with pip:

```sh
pip install bad-spence
```

## Usage

```sh
spence <doi_path> [-s sort]
```

The `<doi_path>` is a text file containing a list of DOI separated by line breaks.
